@@ -562,7 +562,7 @@ class DataTransform(forms.ModelForm):
                 instance=self.instance,
                 data=self.data if self.is_bound else None,
                 files=self.files if self.is_bound else None,
-                initial=[{'parent': self.instance}]
+                initial=[{'parent': self.instance.id}]
             )
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
@@ -620,13 +620,13 @@ class DataTransformRoot(forms.ModelForm):
         if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                                  fk_name='parent', form=DataTransform,
-                                                                 extra=0
+                                                                 extra=1
                                                                  )
             self.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=self.instance,
                 data=self.data if self.is_bound else None,
                 files=self.files if self.is_bound else None,
-                initial=[{'parent': self.instance}]
+                initial=[{'parent': self.instance.id}]
             )
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
